django\_teams
=============

[![Build Status](https://travis-ci.org/CSDTs/django_teams.svg?branch=master)](https://travis-ci.org/CSDTs/django_teams)[![Updates](https://pyup.io/repos/github/CSDTs/django_teams/shield.svg)](https://pyup.io/repos/github/CSDTs/django_teams/)[![Coverage Status](https://coveralls.io/repos/github/CSDTs/django_teams/badge.svg?branch=master)](https://coveralls.io/github/CSDTs/django_teams?branch=master)

This project aims to provide an easy-to-use method for restricting row-based access to models based on "teams".
Teams control objects, and can specify who is allowed to read, create, update, and delete objects.

This repository originally written by chuck211991, modified for rpi_csdt_community.
